"use strict";
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (Object.hasOwnProperty.call(mod, k)) result[k] = mod[k];
    result["default"] = mod;
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
const ts_simple_ast_1 = __importStar(require("ts-simple-ast"));
function createProjectFiles(config) {
    let project = new ts_simple_ast_1.default({
        compilerOptions: {
            target: ts_simple_ast_1.ScriptTarget.ES2018,
            module: ts_simple_ast_1.ModuleKind.CommonJS,
            lib: [
                "es2018"
            ]
        },
        useVirtualFileSystem: true
    });
    const result = { project, files: {} };
    config.files.forEach(f => {
        result.files[f.name] = project.createSourceFile(f.path, f.text);
    });
    return result;
}
exports.createProjectFiles = createProjectFiles;
function modifyAndAssert({ node, modification, asserts, verbose = false }) {
    asserts.filter(a => a.before && a.file).forEach(({ before, after, file }) => {
        expect(file.getText()).toContain(before);
        if (after) {
            expect(file.getText()).not.toContain(after, `OFFENDING file: ${file.getFilePath()}`);
        }
    });
    if (node && modification) {
        verbose && console.log('BEFORE: ' + node.getText());
        modification(node);
        verbose && console.log('AFTER: ' + node.getText());
    }
    asserts.filter(a => a.after && a.file).forEach(({ before, after, file }) => {
        if (before) {
            expect(file.getText()).not.toContain(before, `OFFENDING file: ${file.getFilePath()}`);
        }
        expect(file.getText()).toContain(after, `OFFENDING file: ${file.getFilePath()}`);
    });
}
exports.modifyAndAssert = modifyAndAssert;
function printDiagnostics(project) {
    console.log(project.getDiagnostics()
        .map(d => d.getMessageText().toString() + ' - ' + d.getSourceFile().getFilePath() + '#' + d.getLineNumber())
        .join('\n'));
}
exports.printDiagnostics = printDiagnostics;
// export function printReferences(helperFunction: NamedNode) {
//   const referencedSymbols = helperFunction.findReferences()
//   for (const referencedSymbol of referencedSymbols) {
//     for (const reference of referencedSymbol.getReferences()) {
//       console.log("---------")
//       console.log("REFERENCE")
//       console.log("---------")
//       console.log("File path: " + reference.getSourceFile().getFilePath());
//       console.log("Start: " + reference.getTextSpan().getStart());
//       console.log("Length: " + reference.getTextSpan().getLength());
//       console.log("Parent kind: " + reference.getNode().getParentOrThrow().getKindName());
//       console.log("\n");
//     }
//   }
// }
//# sourceMappingURL=ts-simple-ast-test-util.js.map