"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const path_1 = require("path");
const ts_simple_ast_1 = __importDefault(require("ts-simple-ast"));
/** gets the config file of given ts project or undefined if given is not a ConfiguredProject or tsconfig cannot be found */
function getConfigFilePath(project) {
    if (project.getConfigFilePath) {
        return project.getConfigFilePath();
    }
    else {
        // workaround - probably this project is not configured
        return project.getFileNames().find(p => path_1.basename(p.toString()) === 'tsconfig.json');
    }
    // TODO: for integrate it in simple-ast try with findConfigFile
}
exports.getConfigFilePath = getConfigFilePath;
/**
 * (dirty way) of creating a ts-simple-ast Project from an exiting ts.server.Project. Given project must be a
 * configured project (created with a tsconfig file. It will recreates the project from scratch so it can take
 * some time. Use it with discretion
 */
function createSimpleASTProject(nativeProjectOrPath) {
    const tsConfigFilePath = typeof nativeProjectOrPath === 'string' ? nativeProjectOrPath : getConfigFilePath(nativeProjectOrPath);
    const project = new ts_simple_ast_1.default({
        tsConfigFilePath
    });
    return project;
}
exports.createSimpleASTProject = createSimpleASTProject;
/**
 * like getChildren but using forEachChild(). TODO: perhaps is a good idea to add a useForEachChild to ts-simple-ast getChildren that is optional but if provided do this ?
 */
function getChildrenForEachChild(n) {
    const result = [];
    n.forEachChild(n => result.push(n));
    return result;
}
exports.getChildrenForEachChild = getChildrenForEachChild;
/**
 *  try to call n.getName or returns empty string if there is no such method
 * @param n
 */
function getName(n) {
    return n.getName ? (n.getName() + '') : '';
}
exports.getName = getName;
// encapsulate simple project creation here so we can start testing caching the project and refreshing it instead of fully create it
function getSimpleProject(project) {
    // TODO: try to cache and do unit test simulating TLS
    // if(!simpleProject){
    let tsConfigPath = getConfigFilePath(project);
    let simpleProject = createSimpleASTProject(tsConfigPath);
    // }
    return simpleProject;
}
exports.getSimpleProject = getSimpleProject;
//# sourceMappingURL=ts-simple-ast-util.js.map